====================
Beam Section Profile
====================

The Beam Section profile commands are used to create profiles. A profile definition specifies the properties of a beam that are related to its cross-section geometry. When you define a beam section, you must include a reference to a profile in the section definition.

Create beam section profiles
----------------------------

In Mdb
~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileModel.BeamSectionProfileModel
    :members:
    :special-members: __init__

In Odb
~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileOdb.BeamSectionProfileOdb
    :members:
    :special-members: __init__

    .. autoclasstoc::


Classes
-------

Profile
~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.Profile.Profile
    :members:
    :special-members: __init__

    .. autoclasstoc::

ArbitraryProfile
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.ArbitraryProfile.ArbitraryProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

BoxProfile
~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BoxProfile.BoxProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

CircularProfile
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.CircularProfile.CircularProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

GeneralizedProfile
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.GeneralizedProfile.GeneralizedProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

HexagonalProfile
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.HexagonalProfile.HexagonalProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

IProfile
~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.IProfile.IProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

LProfile
~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.LProfile.LProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

PipeProfile
~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.PipeProfile.PipeProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

RectangularProfile
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.RectangularProfile.RectangularProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

TProfile
~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.TProfile.TProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

TrapezoidalProfile
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.TrapezoidalProfile.TrapezoidalProfile
    :members:
    :special-members: __init__

    .. autoclasstoc::

